==> 0.0.4.zip: phyrepanel-mirror/web/app/Filament/Resources/BackupResource/Widgets/BackupStats.php <==
<?php

namespace app\Filament\Resources\BackupResource\Widgets;

use App\Filament\Resources\BackupResource\Pages\ListBackups;
use App\Filament\Resources\Shop\OrderResource\Pages\ListOrders;
use App\Models\Backup;
use Filament\Widgets\Concerns\InteractsWithPageTable;
use Filament\Widgets\StatsOverviewWidget as BaseWidget;
use Filament\Widgets\StatsOverviewWidget\Stat;
use Flowframe\Trend\Trend;
use Flowframe\Trend\TrendValue;

class BackupStats extends BaseWidget
{
    use InteractsWithPageTable;

    protected static ?string $pollingInterval = null;

    protected function getTablePage(): string
    {
        return ListBackups::class;
    }

    protected function getStats(): array
    {
        $findBackups = Backup::select(['id'])->where('status', 'processing')->get();
        if ($findBackups->count() > 0) {
            foreach ($findBackups as $backup) {
                $backup->checkBackup();
            }
        }
        $usedSpace = 0;
        $backupPath = storage_path('backups');
        if (is_dir($backupPath)) {
            $usedSpace = $this->getDirectorySize($backupPath);
        }

        return [
            Stat::make('Total backups', Backup::count()),
            Stat::make('Total used space', $usedSpace),
        ];
    }

    public function getDirectorySize($path)
    {
        $output = shell_exec('du -sh ' . $path);
        $output = explode("\t", $output);

        if (isset($output[0])) {
            return $output[0];
        }

        return 0;
    }
}

==> 0.1.0.zip: phyrepanel-mirror/web/app/Filament/Resources/BackupResource/Widgets/BackupStats.php <==
<?php

namespace app\Filament\Resources\BackupResource\Widgets;

use App\BackupStorage;
use App\Filament\Resources\BackupResource\Pages\ListBackups;
use App\Filament\Resources\Shop\OrderResource\Pages\ListOrders;
use App\Models\Backup;
use Filament\Widgets\Concerns\InteractsWithPageTable;
use Filament\Widgets\StatsOverviewWidget as BaseWidget;
use Filament\Widgets\StatsOverviewWidget\Stat;
use Flowframe\Trend\Trend;
use Flowframe\Trend\TrendValue;
use Illuminate\Support\Facades\Cache;

class BackupStats extends BaseWidget
{
    use InteractsWithPageTable;

    protected static ?string $pollingInterval = null;

    protected function getTablePage(): string
    {
        return ListBackups::class;
    }

    protected function getStats(): array
    {

        $stats = Cache::remember('backup-stats', 300, function () {
            $usedSpace = 0;
            $backupPath = BackupStorage::getPath();
            if (is_dir($backupPath)) {
                $usedSpace = $this->getDirectorySize($backupPath);
            }
            return [
                'totalBackups' => Backup::count(),
                'usedSpace' => $usedSpace,
            ];
        });

        return [
            Stat::make('Total backups', $stats['totalBackups']),
            Stat::make('Total used space', $stats['usedSpace']),
        ];
    }

    public function getDirectorySize($path)
    {
        $output = shell_exec('du -sh ' . $path);
        $output = explode("\t", $output);

        if (isset($output[0])) {
            return $output[0];
        }

        return 0;
    }
}
